# Generated by Django 2.1.11 on 2019-08-27 14:01

from django.db import migrations, models
import django_extensions.db.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='InterfaceHistory',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', django_extensions.db.fields.CreationDateTimeField(auto_now_add=True, verbose_name='created')),
                ('modified', django_extensions.db.fields.ModificationDateTimeField(auto_now=True, verbose_name='modified')),
                ('service_name', models.CharField(blank=True, max_length=500, null=True, verbose_name='服务名称')),
                ('url', models.CharField(blank=True, max_length=500, null=True, verbose_name='服务地址')),
                ('method', models.CharField(blank=True, max_length=50, null=True, verbose_name='方式')),
                ('payload', models.TextField(blank=True, null=True, verbose_name='输入参数')),
                ('http_status', models.CharField(blank=True, max_length=50, null=True, verbose_name='HTTP请求状态码')),
                ('http_response_header', models.TextField(blank=True, null=True, verbose_name='HTTP响应头信息')),
                ('http_response_content', models.TextField(blank=True, null=True, verbose_name='HTTP响应消息体')),
                ('http_error', models.TextField(blank=True, null=True, verbose_name='HTTP连接错误信息')),
                ('time_it', models.IntegerField(default=0, help_text='毫秒', verbose_name='服务响应时间')),
            ],
            options={
                'verbose_name': '接口日志',
                'verbose_name_plural': '接口日志',
            },
        ),
    ]
